﻿using System.Collections.Generic;

namespace SilverData
{
	public class SilverSort : List<SilverSortItem>
	{

		public SilverSort()
			: base()
		{
		}

		public new void Add(SilverSortItem element)
		{
			if( element == null || string.IsNullOrEmpty( element.Target_column_name))
				return;

			SilverSortItem	e	= this[element.Target_column_name];

			if( e == null)
				base.Add( element);
			else
				e.CopyOther( element);
		}

		public void Add(string field_name, sort_direction direction)
		{
			if (string.IsNullOrEmpty(field_name))
				return;

			SilverSortItem e = this[field_name];

			if (e == null)
				base.Add(new SilverSortItem(field_name, direction));
			else
			{
				e.Target_column_name	= field_name;
				e.Sort_direction		= direction;
			}
		}


		public new void AddRange(IEnumerable<SilverSortItem> other)
		{
			if( other == null)
				return;

			foreach (SilverSortItem e in other)
			{
				this.Add( e);
			}
		}

		public SilverSortItem this[string field_name]
		{
			get
			{
				if( string.IsNullOrEmpty( field_name) || Count <= 0)
					return null;

				foreach (SilverSortItem e in this)
				{
					if( string.Compare( e.Target_column_name, field_name, true) == 0)
						return e;
				}
				return null;
			}
			//set { /* set the specified index to value here */ }
		}

		public override string ToString()
		{
			return StrSql;
		}

		public string StrSql
		{
			get
			{
				if (Count <= 0)
					return "";

				string str_ret = "";

				foreach (SilverSortItem s in this)
				{
					if( str_ret.Length > 0)
						str_ret	+= ", ";

					str_ret += s.StrSql;
				}
				return str_ret;
			}
		}

	}
}
